backup

Function backup 

pub fn backup(path: &Path) -> Result<()>
Creates a backup copy of a file with a timestamped extension.

Arguments

  • path - The file to back up

Returns

Ok(()) if the backup was created or the file doesn’t exist.